@@ -34,9 +34,8 @@ vistla.formula<-function(formula,data,...,yn){
 #'  The default value of 0 turns of this filtering.
 #'  The same effect can be later achieved with the \code{\link{prune}} function.
 #' @param targets a vector of target feature names.
-#'  If given, the algorithm will stop just after reaching the last of them, rather than after tracing all paths from the root.
-#'  The same effect can be later achieved with the \code{\link{prune}} function.
-#'  This is a simple method to remove irrelevant paths, yet it comes with a substantial increase in computational burden.
+#'  If given, the algorithm will stop just after reaching the last feature from this list, rather than after tracing paths to all targets.
+#'  The same effect can be later achieved with the \code{\link{prune}} function, but restricting targets here saves computational time.
 #' @param verbose when set to \code{TRUE}, turns on reporting of the algorithm progress.
 #' @param estimator mutual information estimator to use.
 #'  \code{"mle"} --- maximal likelihood, requires all features to be discrete (factors or booleans).
@@ -176,21 +175,3 @@ mi_scores<-function(x){
  ans
 }
 
-#' Extract leaf scores of vertex pairs
-#'
-#' Produces a matrix \eqn{S} where \eqn{S_{ij}} is a score
-#'  of the path ending in vertices \eqn{i} and \eqn{j}.
-#' Since vistla works on vertex pairs, this value is unique.
-#' This can be interpreted as a feature similarity matrix
-#'  in context of the current vistla root.
-#' @note This function should be called on an unpruned vistla tree,
-#'  otherwise the result will be mostly composed of zeroes.
-#' @param x vistla object.
-#' @return A square matrix with leaf scores of all feature pairs.
-#' @export
-leaf_scores<-function(x){
- stopifnot(inherits(x,"vistla"))
- x$mi*0->ans
- ans[as.matrix(x$tree[,c("b","c")])]<-x$tree$score
- ans
-}
